clear all
global R t m g E epsilon

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1. Finding the parameters of the model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

R=0.2;%ratio of citations:(1446 / 7331)% ratio of patents: 155 /892
t=0.13;
m=1.2;
E=0.03;
g=0.02;
epsilon=0.185; %for citations

% find an initial guess
% we want to see whether we will be able to find an initial guess. For that
% we have transformed everything as a function of etaL.

%fplot(@(x) etaLfuncMwithE(x),[1 2]); % just checking that there is a unique solution for the initial guess

etaL0=fzero(@etaLfuncMwithE,m);
etaH0=(1+epsilon*t/(E*(epsilon*t+1/etaL0)*(1/R+1)))*etaL0;
mu0=E*(epsilon*t+1/etaL0)*(1/R+1)*etaH0;
xI0=mu0/(1+R);
xE0=R*xI0;
phi0=g/(xI0*log(etaH0))-R;
L0=100/(1-1/etaL0)*(t-mu0*(1/etaL0-1/etaH0))-1;

% full solution
options=optimset('TolFun',1e-25,'TolX',1e-25,'Display','Iter','MaxFunEvals',10000,'Algorithm','active-set','MaxIter',1000000);
optionssol=optimset('MaxFunEvals',100000,'MaxIter',1000000);

tetaI0=(1/etaL0-1/etaH0)/xI0;
tetaE0=(1-1/etaH0)/xE0;
param0=[etaL0;etaH0;tetaI0;tetaE0;L0];

[param, val]=fsolve(@(par) momentLvecwithE(par),param0,optionssol); % this is the actual solution

% check the results
etaL=param(1)
etaH=param(2)
tetaI=param(3)
tetaE=param(4)
L=param(5)

xI=(1/etaL-1/etaH)/tetaI
xE=(1-1/etaH-1/L*1/etaL+1/L*(1/etaL-1/etaH)^2/tetaI)/(tetaE-1/L*(1/etaL-1/etaH))
mu=xI+xE

phi=g/(xI*log(etaH))-R % phi can be solved separately at the end

% sign of dtop1/detaL
dtop1detaL=((1+L)/100-mu-xI+1/L*((1-2*xI)*(tetaE-(1/etaL-1/etaH)/L)-(1-1/etaH-1/(L*etaL)+(1/etaL-1/etaH)/...
    (xI*L)))*(1/etaL-1/etaH)/(tetaE-(1/etaL-1/etaH)/L)^2)/etaL^2
% this just checks that an increase in etaL increases the top 1% share for
% our parameters

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%2. Creating a simulated dataset 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%We need 51 states and 28 observations

% First we create noise, to do so we assume a vector of errors
% We try to hit the following values in the data (reported in table D1):
% - s.d. of the state fixed effects: 0.173
% - s.d. of the year fixed effects: 0.325
% - s.d. of log Cit5: 1.348
% - s.d. of log Cit5 controlling for state fixed effects: 0.744
% - s.d. of predicted log Cit5: 1.057 
% - s.d. of predicted log Cit5 controlling for state fixed effects: 0.702
% - s.d. of top income inequality: 0.046
% - OLS coefficient: 0.049

% Definition of the distributions
epsdist=makedist('Normal','mu',-1/2*(0.07)^2,'sigma',0.07); % final error
epsst=makedist('Normal','mu',-1/2*(0.0)^2,'sigma',0.0); % state fixed effect
Epsye=makedist('Normal','mu',-1/2*(0.325)^2,'sigma',0.325); % year fixed effect
epstet=makedist('Normal','mu',1/2*(0.72)^2,'sigma',0.72); % state-year shock on teta
epstetst=makedist('Normal','mu',1/2*(0.62)^2,'sigma',0.62); % state shock on teta
epspat=makedist('Normal','mu',-1/2*(0.47)^2,'sigma',0.47); % measurement error on patent
gap=0.6*min(etaL-1,etaH-etaL);
gapst=0.4*min(etaL-1,etaH-etaL);
epseta=makedist('Uniform','lower',-gap,'upper',gap); % state-year shock on etaL
epsetast=makedist('Uniform','lower',-gapst,'upper',gapst); % state shock on etaL

% Second we create 500 draws of the data

Dataeta=zeros(51*28,14); %initialize a matrix to contain the data for one draw
% Extract parameters to csv
dlmwrite('param.csv',[etaH etaL tetaI tetaE L], 'precision', 9);

for i = 1:500 
    % Each i is a draw of the data
    epsye=random(Epsye,28,1); % year error
    for st=1:51
        errst=random(epsst); % state error
        erretast=random(epsetast); % state shock on eta:
        errtetst=random(epstetst); % state shock on teta
        for year=1:28
            Dataeta((st-1)*28+year,1)=st; % state
            Dataeta((st-1)*28+year,2)=year; % year
            err=random(epsdist);
            errtet=random(epstet)+errtetst; % total shock on teta
            erretaL=random(epseta)+erretast; % total shock on etaL
            tetaIloc=tetaI*exp(errtet);
            tetaEloc=tetaE*exp(errtet);
            etaLloc=etaL+erretaL;
            xIloc=(1/etaLloc-1/etaH)/tetaIloc;
            xEloc=max(0,(1-1/etaH-1/L*1/etaLloc+1/L*(1/etaLloc-1/etaH)^2/tetaIloc)/(tetaEloc-1/L*(1/etaLloc-1/etaH)));
            muloc=min(xIloc+xEloc,1);
            Dataeta((st-1)*28+year,3)=muloc; % innovation
            if 1/100 < muloc/(1+L)
                toploc=(1+L)/100*(1-1/etaH);
            else
                if 1+L<=100
                    toploc=muloc*(1/etaLloc-1/etaH)+(1+L)/100*(1-1/etaLloc);
                else
                    toploc=muloc*(1/etaLloc-1/etaH)*(1-((1+L)/100-1)/L)+1-1/etaLloc+((1+L)/100-1)/(L*etaLloc);
                end
            end
            Dataeta((st-1)*28+year,5)=toploc; % predicted top 1 if no error
            Dataeta((st-1)*28+year,9)=toploc*exp(errst+epsye(year)); % predicted to 1 with state and year error
            toploc=toploc*exp(err+errst+epsye(year)); % final predicted top 1
            Dataeta((st-1)*28+year,4)=toploc; % predicted top 1
            Dataeta((st-1)*28+year,6)=xIloc; % incumbent innovation
            Dataeta((st-1)*28+year,7)=xEloc; % entrant innovation
            Dataeta((st-1)*28+year,8)=errtet; % total shock on teta
            errpat=random(epspat);
            Dataeta((st-1)*28+year,10)=muloc*exp(errpat); % innovation measured with error
            Dataeta((st-1)*28+year,11)=xEloc/xIloc; % ratio entrant to incumbent
            Dataeta((st-1)*28+year,12)=muloc*etaH+(1-muloc)*etaLloc; % average mark-up
            Dataeta((st-1)*28+year,13)=xEloc/etaH/(muloc/etaH+(1-muloc)/etaL);% employment share
            Dataeta((st-1)*28+year,14)=(phi*xIloc+xEloc)*log(etaH); % growth
        end
    end

file = strcat('data',int2str(i));   
file = strcat(file, '.csv');
dlmwrite(file,Dataeta, 'precision', 9);
end