//Main Figures and Tables replication 

use ../data/main_db, clear 

global graph = "../graphs" //Set the path for the graphs
sysdir set PLUS "C:/ado/PLUS" 
// Note: you need the synth command installed, this could be done by typing
// ssc install synth
// or by downloading the ado files here:
// https://ideas.repec.org/c/boc/bocode/s457334.html

mata: mata mlib index // For the synth command to run the optimization procedure
set scheme s1mono, perm

//Table 1: Descriptive statistics by measures of innovation and for the top 1% income share in two distinctive years
//Corresponds to Table 1 in the paper
preserve
	qui {
	foreach var of varlist patent Cit5_corr claim generality Top5 Top1 {
		replace `var' = `var'/pop*1000000
	}
	foreach var of varlist patent Cit5_corr claim generality Top5 Top1 {
		replace `var' = round(`var')
	}
	replace top1_adj = round(top1_adj*100)/100
	}
	tabstat top1_adj patent Cit5_corr claim generality Top5 Top1 if year == 1980, s(mean p25 p50 p75 min max) 
	tabstat top1_adj patent Cit5_corr claim generality Top5 Top1 if year == 2005, s(mean p25 p50 p75 min max)
restore

//Table 2: Mean and Standard Deviation of the main variables
//Corresponds to Table 2 in the paper
preserve
	qui {
		keep if inrange(year, 1980, 2005)
		gen innov1 = log(1000000*Cit5_corr/pop)
		gen innov2 = log(1000000*patent/pop)	
		label var lgdppc "Gdppc (log)"
		keep  lgdppc ltop1 innov1 innov2 finance gvt unemp tax_gain tax_rate_wage popgrowth
		rename innov1 Citations
		rename innov2 patent
		rename tax_gain taxK
		rename tax_rate_wage taxL
	}
	tabstat *, s(mean sd) labelwidth(32)
restore

//Figures

//Graph 1: Innovation and Top 1% income share in the US. 1963-2010
//Corresponds to Figure 1a in the paper
preserve
	use ../data/top1_us, clear
	keep if inrange(year, 1963, 2009)
	replace patent = patent
	label var top1 "Top 1% income share"
	label var patent "Number of granted patents"
	twoway (line top1 year, legend(label(1 "Top 1% Income Share")) ) (line patent year, yaxis(2) legend(label(2 "Patents")))
	graph export  "${graph}/graph1.eps", replace as(eps)
restore

//Graph 2: Evolution of innovation and inequality 1980-2005
//Corresponds to Figure 1b in the paper
preserve
	keep if year == 1980 | year == 2005
	keep Cit5_corr top1_adj year iso pop 
	replace Cit5_corr = Cit5_corr/pop
	drop pop 
	reshape wide Cit5_corr top1_adj, i(iso) j(year)
	gen delta_log_cit = log(Cit5_corr2005/Cit5_corr1980)
	gen delta_log_top1 = log(top1_adj2005/top1_adj1980)
	label var delta_log_cit "Change in the log of citations per capita"
	label var delta_log_top1 "Change in the log of the top 1% income share"
	twoway (scatter  delta_log_cit delta_log_top1 , mlabel(iso) msize(small) ytitle(Change in the log of citations per capita) legend(off)) (lfit   delta_log_cit delta_log_top1)
	graph export  "${graph}/graph2.eps", replace as(eps)
restore

//Graph3: Top 1% income share and Gini coeefficient against innovation
//Corresponds to Figure 2 in the paper
preserve
	gen innov = log(Cit5_corr/pop)
	keep if inrange(year, 1976, 2009)
	
	xtile cent = innov, nq(20)
	collapse (mean) top1_adj top10_adj gini99, by(cent)
	sort cent
	gen top1_std = top1_adj / top1_adj[1]
	gen gini99_std = gini99 / gini99[1]
	gen top10_std = top10_adj/top10_adj[1]

	label var top1_std "Top 1% Income share"
	label var gini99_std "Bottom 99% Gini"
	label var cent "20 quantiles of innovation intensity"
	twoway (line top1_std gini99_std cent)
	graph export  "${graph}/graph3.eps", replace as(eps)
restore

//Graph 4
//Corresponds to Figure 3 in the paper
preserve
	use ../data/CZ_main, clear
	keep if urban
	gen innov =  log(1000000*patent/pop)
	xtile cent = innov, nq(20)
	gen mob = log(pq5q1)
	collapse (mean) mob innov, by(cent)
	label var cent "20 quantiles of innovation"
	label var mob "Measure of Mobility"
	twoway connected mob cent
	graph export  "${graph}/graph4.eps", replace as(eps)	
restore

//Note: Figure 4 in the paper has been constructed using powerpoint
//It does not use any data


//Graphs 5a-5b
//Corresponds to Figures 5a-5b in the paper
preserve
	sort id year
	drop if iso == "DC"	
	su id if iso == "KY"
	local tru = r(mean) 
	local trp = 1993
	local first_year = 1983 
	local last_year = 2001 
	local year_stop = `trp' - 2

	keep if inrange(year, `first_year', `last_year')
	sort id year
	gen g = D.gdp/L.gdp
	synth Cit5_corr_univ  finance gvt  g  pop share_manuf rho_low  , tru(`tru') trp(`trp') xperiod(`first_year'(1)`year_stop')  nested allopt  keep(synth_result) replace 

	use synth_result, clear
	set scheme s1mono, perm
	drop in 1
	rename _time year
	rename _Y_s KY_synth
	rename _Y_treated KY_real
	drop if year == .
	sort year
	drop _*
	label var year "Year"
	label var KY_synth "Synthetic KY"
	label var KY_real "Actual KY"
	twoway line KY_synth KY_real year, xline(`trp') ytitle(Citations to university patents)
	graph export  "${graph}/graph5a.eps", replace as(eps)
	erase synth_result.dta
restore


preserve
	sort id year
	drop if iso == "DC"	
	drop if year == .
	su id if iso == "KY"
	local tru = r(mean) 
	local trp = 1993
	local first_year = 1983 
	local last_year = 2001
	local year_stop = `trp' - 2

	keep if inrange(year, `first_year', `last_year')
	set scheme s1color
	sort id year
	gen g = D.gdp/L.gdp
	synth Cit5_corr  finance gvt  g  pop share_manuf rho_low  , tru(`tru') trp(`trp') xperiod(`first_year'(1)`year_stop')  nested allopt  keep(synth_result) replace 

	use synth_result, clear
	set scheme s1mono, perm
	drop in 1
	rename _time year
	rename _Y_s KY_synth
	rename _Y_treated KY_real
	drop if year == .
	sort year
	drop _*
	label var year "Year"
	label var KY_synth "Synthetic KY"
	label var KY_real "Actual KY"
	local trp3 = `trp'+3
	twoway line KY_synth KY_real year, xline(`trp') lpattern(solid) xline(`trp3') lpattern(dash) ytitle(Citations to patents)
	graph export  "${graph}/graph5b.eps", replace as(eps)	
	erase synth_result.dta
restore


// Graphs 6a-6c Event studies
// Corresponds to Figure 6a-6c in the paper
// Note: the earmarks data have been sent to us directly by Lauren Cohen
// They are not directly available from their paper so we do not release them
// Hence Figure 6c is not available
// Please contact them directly and get in touch with us if you want to replicate this figure

foreach innov in "Cit5" "Cit5_univ"  {
	preserve
		drop if iso == "DC"
			local t_max = 6
			local t_min = -4
			if "`innov'" == "Cit5" {
				local year_min = 1976-`t_min'
				local year_max = 2006-`t_max'
			}
			if "`innov'" == "Cit5_univ" {
				local year_min = 1980-`t_min'
				local year_max = 2006-`t_max'
			}	
			sort id year
			by id: gen change = ((L.SenateMember == 0 & SenateMember == 1) | (L.SenateMember == 1 & SenateMember == 2)) & inrange(year, `year_min', `year_max')

			bys year: egen den = sum(`innov')
			gen innov = `innov'/den
			drop den
			sort id year
			by id: egen tot_change = sum(change)
			keep if tot_change != 0
			bys id: egen date_change = min(year*(change==1)+100000*(change == 0))
			gen t = year - date_change

			qui xi:areg innov i.id*year, a(id)
			predict res, r
			replace innov = res
			

			keep if inrange(t, `t_min', `t_max')
			
			collapse (mean) innov SenateMember , by(t)
			label var t "Distance to event"
			label var Senate "Number of senators in the committee"
			if "`innov'" == "Cit5" {
				label var innov "Share of citations, all patents"
			}
			if "`innov'" == "Cit5_univ" {
				label var innov "Share of citations, university patents"
			}	
			if "`innov'" == "earmarks" {
				label var innov "Share of earmarks"		
			}	
			
			if "`innov'" == "Cit5" {
				twoway (connected innov t, xline(0) xline(3,  lpattern(dash))) (connected Senate t, yaxis(2)) 
				graph export  "${graph}/graph6a.eps", replace as(eps)

			}
			else if "`innov'" == "Cit5_univ" {
				twoway (connected innov t, xline(0)) (connected Senate t, yaxis(2))
				graph export  "${graph}/graph6b.eps", replace as(eps)
			}		
	restore
}
